// Coselica Toolbox for Xcos
// Copyright (C) 2011 - DIGITEO - Bruno JOFRET
// Copyright (C) 2009  Dirk Reusch, Kybernetik Dr. Reusch
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.

function [x,y,typ]=CMR_Brake(job,arg1,arg2)
x=[];y=[];typ=[];
select job
  case 'plot' then
    mue_pos=arg1.graphics.exprs(1);
    peak=arg1.graphics.exprs(2);
    cgeo=arg1.graphics.exprs(3);
    fn_max=arg1.graphics.exprs(4);
    mode_start=arg1.graphics.exprs(5);
    standard_draw(arg1,%f,_CMR_Brake_dp);
  case 'getinputs' then
    [x,y,typ]=_CMR_Brake_ip(arg1);
  case 'getoutputs' then
    [x,y,typ]=_CMR_Brake_op(arg1);
  case 'getorigin' then
    [x,y]=standard_origin(arg1);
  case 'set' then
    x=arg1;
    graphics=arg1.graphics;exprs=graphics.exprs;
    model=arg1.model;
    while %t do
      [ok,mue_pos,peak,cgeo,fn_max,mode_start,exprs]=...
        getvalue(['';'CMR_Brake';'';'Brake based on Coulomb friction ';''],...
        [' mue_pos [-] : mue > 0, positive sliding friction coefficient (w_rel>=0)';' peak [-] : peak >= 1, peak*mue_pos = maximum value of mue for w_rel==0';' cgeo [-] : cgeo >= 0, Geometry constant containing friction distribution assumption';' fn_max [N] : fn_max >= 0, Maximum normal force';' mode_start [-] : Initial sliding mode (-1=Backward,0=Sticking,1=Forward,2=Free)'],...
        list('vec',1,'vec',1,'vec',1,'vec',1,'vec',1),exprs);
      if ~ok then break, end
      model.equations.parameters(2)=list(mue_pos,peak,cgeo,fn_max,mode_start)
      graphics.exprs=exprs;
      x.graphics=graphics;x.model=model;
      break
    end
  case 'define' then
    model=scicos_model();
    mue_pos=0.5;
    peak=1;
    cgeo=1;
    fn_max=1;
    mode_start=0;
    model.sim='CMR_Brake';
    model.blocktype='c';
    model.dep_ut=[%t %f];
    mo=modelica();
      mo.model='CMR_Brake';
      mo.inputs=['flange_a','f_normalized'];
      mo.outputs=['flange_b','bearing'];
      mo.parameters=list(['mue_pos','peak','cgeo','fn_max','mode_start'],...
                         list(mue_pos,peak,cgeo,fn_max,mode_start),...
                         [0,0,0,0,0]);
    model.equations=mo;
    model.in=ones(size(mo.inputs,'*'),1);
    model.out=ones(size(mo.outputs,'*'),1);
    exprs=[sci2exp(mue_pos);sci2exp(peak);sci2exp(cgeo);sci2exp(fn_max);sci2exp(mode_start)];
    gr_i=[...
          'if orient then';...
          '  xx=orig(1);yy=orig(2);';...
          '  ww=sz(1);hh=sz(2);';...
          'else';...
          '  xx=orig(1)+sz(1);yy=orig(2);';...
          '  ww=-sz(1);hh=sz(2);';...
          'end';...
          'if orient then';...
          '  xrect(orig(1)+sz(1)*0.4,orig(2)+sz(2)*0.1,sz(1)*0.2,sz(2)*0.2);';...
          'else';...
          '  xrect(orig(1)+sz(1)*(1-0.4-0.2),orig(2)+sz(2)*0.1,sz(1)*0.2,sz(2)*0.2);';...
          'end';...
          'e=gce();';...
          'e.visible=""on"";';...
          'e.foreground=color(192,192,192);';...
          'e.background=color(192,192,192);';...
          'e.fill_mode=""on"";';...
          'e.thickness=0.25;';...
          'xpoly(xx+ww*[0.315;0.315;0.685;0.685;0.665;0.665;0.335;0.335;0.315],yy+hh*[0.225;0.05;0.05;0.225;0.225;0.07;0.07;0.225;0.225]);';...
          'e=gce();';...
          'e.visible=""on"";';...
          'e.foreground=color(192,192,192);';...
          'e.background=color(192,192,192);';...
          'e.fill_mode=""on"";';...
          'e.thickness=0.25;';...
          'if orient then';...
          '  xrect(orig(1)+sz(1)*0,orig(2)+sz(2)*0.55,sz(1)*0.4,sz(2)*0.1);';...
          'else';...
          '  xrect(orig(1)+sz(1)*(1-0-0.4),orig(2)+sz(2)*0.55,sz(1)*0.4,sz(2)*0.1);';...
          'end';...
          'e=gce();';...
          'e.visible=""on"";';...
          'e.foreground=color(0,0,0);';...
          'e.background=color(192,192,192);';...
          'e.fill_mode=""on"";';...
          'e.thickness=0.25;';...
          'if orient then';...
          '  xrect(orig(1)+sz(1)*0.4,orig(2)+sz(2)*0.8,sz(1)*0.2,sz(2)*0.6);';...
          'else';...
          '  xrect(orig(1)+sz(1)*(1-0.4-0.2),orig(2)+sz(2)*0.8,sz(1)*0.2,sz(2)*0.6);';...
          'end';...
          'e=gce();';...
          'e.visible=""on"";';...
          'e.foreground=color(0,0,0);';...
          'e.background=color(192,192,192);';...
          'e.fill_mode=""on"";';...
          'e.thickness=0.25;';...
          'if orient then';...
          '  xrect(orig(1)+sz(1)*0.6,orig(2)+sz(2)*0.55,sz(1)*0.4,sz(2)*0.1);';...
          'else';...
          '  xrect(orig(1)+sz(1)*(1-0.6-0.4),orig(2)+sz(2)*0.55,sz(1)*0.4,sz(2)*0.1);';...
          'end';...
          'e=gce();';...
          'e.visible=""on"";';...
          'e.foreground=color(0,0,0);';...
          'e.background=color(192,192,192);';...
          'e.fill_mode=""on"";';...
          'e.thickness=0.25;';...
          'xpoly(xx+ww*[0.7;0.85;0.85;0.7],yy+hh*[0.3;0.35;0.25;0.3]);';...
          'e=gce();';...
          'e.visible=""on"";';...
          'e.foreground=color(0,0,255);';...
          'e.background=color(0,0,255);';...
          'e.fill_mode=""on"";';...
          'e.thickness=0.25;';...
          'if orient then';...
          '  xrect(orig(1)+sz(1)*0.65,orig(2)+sz(2)*0.375,sz(1)*0.05,sz(2)*0.15);';...
          'else';...
          '  xrect(orig(1)+sz(1)*(1-0.65-0.05),orig(2)+sz(2)*0.375,sz(1)*0.05,sz(2)*0.15);';...
          'end';...
          'e=gce();';...
          'e.visible=""on"";';...
          'e.foreground=color(0,0,0);';...
          'e.background=color(0,0,0);';...
          'e.fill_mode=""on"";';...
          'e.thickness=0.25;';...
          'xpoly(xx+ww*[0.3;0.15;0.15;0.3],yy+hh*[0.3;0.35;0.25;0.3]);';...
          'e=gce();';...
          'e.visible=""on"";';...
          'e.foreground=color(0,0,255);';...
          'e.background=color(0,0,255);';...
          'e.fill_mode=""on"";';...
          'e.thickness=0.25;';...
          'if orient then';...
          '  xrect(orig(1)+sz(1)*0.3,orig(2)+sz(2)*0.375,sz(1)*0.05,sz(2)*0.15);';...
          'else';...
          '  xrect(orig(1)+sz(1)*(1-0.3-0.05),orig(2)+sz(2)*0.375,sz(1)*0.05,sz(2)*0.15);';...
          'end';...
          'e=gce();';...
          'e.visible=""on"";';...
          'e.foreground=color(0,0,0);';...
          'e.background=color(0,0,0);';...
          'e.fill_mode=""on"";';...
          'e.thickness=0.25;';...
          'xpoly(xx+ww*[0.5;0.9;0.9;0.85],yy+hh*[0.95;0.85;0.3;0.3]);';...
          'e=gce();';...
          'e.visible=""on"";';...
          'e.foreground=color(0,0,255);';...
          'e.thickness=0.25;';...
          'xpoly(xx+ww*[0.5;0.1;0.1;0.15],yy+hh*[0.95;0.85;0.3;0.3]);';...
          'e=gce();';...
          'e.visible=""on"";';...
          'e.foreground=color(0,0,255);';...
          'e.thickness=0.25;';...
          'if orient then';...
          '  xstringb(orig(1)+sz(1)*0,orig(2)+sz(2)*-0.5,""""+model.label+"""",sz(1)*1,sz(2)*0.3,""fill"");';...
          'else';...
          '  xstringb(orig(1)+sz(1)*(1-0-1),orig(2)+sz(2)*-0.5,""""+model.label+"""",sz(1)*1,sz(2)*0.3,""fill"");';...
          'end';...
          'e=gce();';...
          'e.visible=""on"";';...
          'e.foreground=color(0,0,0);';...
          'e.background=color(0,0,255);';...
          'e.fill_mode=""off"";';...
         ];
    x=standard_define([2 2],model,exprs,list(gr_i,0));
    x.graphics.in_implicit=['I','I'];
    x.graphics.in_style=[RotInputStyle(), RealInputStyle()];
    x.graphics.out_implicit=['I','I'];
    x.graphics.out_style=[RotOutputStyle(), RotOutputStyle()];
  end
endfunction
